@@ -1,12 +1,11 @@
 (********************************************************************)
 (*                                                                  *)
 (*  The Why3 Verification Platform   /   The Why3 Development Team  *)
-(*  Copyright 2010-2024 --  Inria - CNRS - Paris-Saclay University  *)
+(*  Copyright 2010-2025 --  Inria - CNRS - Paris-Saclay University  *)
 (*                                                                  *)
 (*  This software is distributed under the terms of the GNU Lesser  *)
 (*  General Public License version 2.1, with the special exception  *)
 (*  on linking described in file LICENSE.                           *)
-(*                                                                  *)
 (********************************************************************)
 
 open Wstdlib
@@ -1830,23 +1829,26 @@ let merge_file_section ~ignore_shapes ~old_ses ~old_theories ~file_is_detached ~
   update_file_node (fun _ -> ()) s f
 
 let read_file env ?format fn =
-  let theories, format = Env.read_file Env.base_language env ?format fn in
-  let ltheories =
-    Mstr.fold
-      (fun name th acc ->
-        (* Hack : with WP [name] and [th.Theory.th_name.Ident.id_string] *)
-        let th_name =
-          Ident.id_register (Ident.id_derive name th.Theory.th_name) in
-         match th.Theory.th_name.Ident.id_loc with
-           | Some l -> (l,th_name,th)::acc
-           | None   -> (Loc.dummy_position,th_name,th)::acc)
-      theories []
-  in
-  let th =  List.sort
-      (fun (l1,_,_) (l2,_,_) -> Loc.compare l1 l2)
-      ltheories
-  in
-  (List.map (fun (_,_,a) -> a) th), format
+  match Env.read_file Env.base_language env ?format fn with
+  | exception Sys_error msg -> (* File not found and other problems opening the file *)
+    raise (Loc.Located (Loc.user_position fn 0 0 0 0, Loc.Message msg))
+  | theories, format ->
+    let ltheories =
+      Mstr.fold
+        (fun name th acc ->
+          (* Hack : with WP [name] and [th.Theory.th_name.Ident.id_string] *)
+          let th_name =
+            Ident.id_register (Ident.id_derive name th.Theory.th_name) in
+          match th.Theory.th_name.Ident.id_loc with
+            | Some l -> (l,th_name,th)::acc
+            | None   -> (Loc.dummy_position,th_name,th)::acc)
+        theories []
+    in
+    let th =  List.sort
+        (fun (l1,_,_) (l2,_,_) -> Loc.compare l1 l2)
+        ltheories
+    in
+    (List.map (fun (_,_,a) -> a) th), format
 
 let merge_file_gen ~ignore_shapes ~reparse_file_fun env (ses : session) (old_ses : session) file =
   let old_theories = file_theories file in
